diff --git a/wagtail/wagtailadmin/hooks.py b/wagtail/wagtailadmin/hooks.py
index 2dd2cd686..c7a89b168 100644
--- a/wagtail/wagtailadmin/hooks.py
+++ b/wagtail/wagtailadmin/hooks.py
@@ -19,7 +19,7 @@ def search_for_hooks():
if not _searched_for_hooks:
for app_module in settings.INSTALLED_APPS:
try:
- import_module('%s.verdant_hooks' % app_module)
+ import_module('%s.wagtail_hooks' % app_module)
except ImportError:
continue
diff --git a/wagtail/wagtailadmin/static/wagtailadmin/css/panels/rich-text.less b/wagtail/wagtailadmin/static/wagtailadmin/css/panels/rich-text.less
index 4c2c5f7be..13528b46a 100644
--- a/wagtail/wagtailadmin/static/wagtailadmin/css/panels/rich-text.less
+++ b/wagtail/wagtailadmin/static/wagtailadmin/css/panels/rich-text.less
@@ -14,7 +14,7 @@
min-height:50px;
overflow: hidden;
- /* Resetting various html tags that have been messed with by Verdant's main css */
+ /* Resetting various html tags that have been messed with by Wagtail's main css */
h1{
text-transform:none;
}
diff --git a/wagtail/wagtailadmin/static/wagtailadmin/js/hallo-plugins/hallo-verdant-toolbar.js b/wagtail/wagtailadmin/static/wagtailadmin/js/hallo-plugins/hallo-wagtail-toolbar.js
similarity index 100%
rename from wagtail/wagtailadmin/static/wagtailadmin/js/hallo-plugins/hallo-verdant-toolbar.js
rename to wagtail/wagtailadmin/static/wagtailadmin/js/hallo-plugins/hallo-wagtail-toolbar.js
diff --git a/wagtail/wagtailadmin/static/wagtailadmin/js/hallo-plugins/hallo-verdantlink.coffee b/wagtail/wagtailadmin/static/wagtailadmin/js/hallo-plugins/hallo-wagtaillink.coffee
similarity index 96%
rename from wagtail/wagtailadmin/static/wagtailadmin/js/hallo-plugins/hallo-verdantlink.coffee
rename to wagtail/wagtailadmin/static/wagtailadmin/js/hallo-plugins/hallo-wagtaillink.coffee
index ef7963690..7f5705065 100644
--- a/wagtail/wagtailadmin/static/wagtailadmin/js/hallo-plugins/hallo-verdantlink.coffee
+++ b/wagtail/wagtailadmin/static/wagtailadmin/js/hallo-plugins/hallo-wagtaillink.coffee
@@ -1,7 +1,7 @@
-# plugin for hallo.js to allow inserting links using Verdant's page chooser
+# plugin for hallo.js to allow inserting links using Wagtail's page chooser
(($) ->
- $.widget "IKS.halloverdantlink",
+ $.widget "IKS.hallowagtaillink",
options:
uuid: ''
editable: null
diff --git a/wagtail/wagtailadmin/static/wagtailadmin/js/page-editor.js b/wagtail/wagtailadmin/static/wagtailadmin/js/page-editor.js
index 3af65aae2..ae4cc5594 100644
--- a/wagtail/wagtailadmin/static/wagtailadmin/js/page-editor.js
+++ b/wagtail/wagtailadmin/static/wagtailadmin/js/page-editor.js
@@ -25,10 +25,10 @@ function makeRichTextEditable(id) {
'hallolists': {},
'hallohr': {},
'halloreundo': {},
- 'halloverdantimage': {},
- 'halloverdantembeds': {},
- 'halloverdantlink': {},
- 'halloverdantdoclink': {},
+ 'hallowagtailimage': {},
+ 'hallowagtailembeds': {},
+ 'hallowagtaillink': {},
+ 'hallowagtaildoclink': {},
}
}).bind('hallomodified', function(event, data) {
input.val(data.content);
@@ -235,7 +235,7 @@ $(function() {
$(this).data('action'),
$('#page-edit-form').serialize(),
function(data, textStatus, request) {
- if (request.getResponseHeader('X-Verdant-Preview') == 'ok') {
+ if (request.getResponseHeader('X-Wagtail-Preview') == 'ok') {
previewWindow.document.open();
previewWindow.document.write(data);
previewWindow.document.close();
diff --git a/wagtail/wagtailadmin/tasks.py b/wagtail/wagtailadmin/tasks.py
index 370ef18ee..e01e48553 100644
--- a/wagtail/wagtailadmin/tasks.py
+++ b/wagtail/wagtailadmin/tasks.py
@@ -57,8 +57,8 @@ def send_notification(page_revision_id, notification, excluded_user_id):
email_content = '\n'.join(rendered_template[1:])
# Get from email
- if hasattr(settings, 'VERDANTADMIN_NOTIFICATION_FROM_EMAIL'):
- from_email = settings.VERDANTADMIN_NOTIFICATION_FROM_EMAIL
+ if hasattr(settings, 'WAGTAILADMIN_NOTIFICATION_FROM_EMAIL'):
+ from_email = settings.WAGTAILADMIN_NOTIFICATION_FROM_EMAIL
elif hasattr(settings, 'DEFAULT_FROM_EMAIL'):
from_email = settings.DEFAULT_FROM_EMAIL
else:
diff --git a/wagtail/wagtailadmin/templates/wagtailadmin/pages/_editor_js.html b/wagtail/wagtailadmin/templates/wagtailadmin/pages/_editor_js.html
index 15bb26589..5b38a05fc 100644
--- a/wagtail/wagtailadmin/templates/wagtailadmin/pages/_editor_js.html
+++ b/wagtail/wagtailadmin/templates/wagtailadmin/pages/_editor_js.html
@@ -10,17 +10,17 @@
-
-
+
+
-
-
-
+
+
+
{% comment %}
- TODO: have a mechanism to specify image-chooser.js (and hallo-verdantimage.coffee)
+ TODO: have a mechanism to specify image-chooser.js (and hallo-wagtailimage.coffee)
within the wagtailimages app -
ideally wagtailadmin shouldn't have to know anything at all about wagtailimages
TODO: a method of injecting these sorts of things on demand when the modal is spawned.
diff --git a/wagtail/wagtailadmin/templates/wagtailadmin/pages/create.html b/wagtail/wagtailadmin/templates/wagtailadmin/pages/create.html
index 87f2fa6fe..230db1181 100644
--- a/wagtail/wagtailadmin/templates/wagtailadmin/pages/create.html
+++ b/wagtail/wagtailadmin/templates/wagtailadmin/pages/create.html
@@ -21,7 +21,7 @@
diff --git a/wagtail/wagtailadmin/templatetags/verdantuserbar.py b/wagtail/wagtailadmin/templatetags/wagtailuserbar.py
similarity index 64%
rename from wagtail/wagtailadmin/templatetags/verdantuserbar.py
rename to wagtail/wagtailadmin/templatetags/wagtailuserbar.py
index 99fece51e..723788812 100644
--- a/wagtail/wagtailadmin/templatetags/verdantuserbar.py
+++ b/wagtail/wagtailadmin/templatetags/wagtailuserbar.py
@@ -3,10 +3,10 @@ from django import template
register = template.Library()
@register.simple_tag(takes_context=True)
-def verdantuserbar(context, cssfile=""):
+def wagtailuserbar(context, cssfile=""):
try:
items = ''.join(["
%s
" % item for item in context['request'].userbar])
context.hasuserbar = True
- return """
%s
""" % (cssfile, items)
+ return """
%s
""" % (cssfile, items)
except AttributeError:
return ''
diff --git a/wagtail/wagtailadmin/views/home.py b/wagtail/wagtailadmin/views/home.py
index e4a1d281d..74e31a0d2 100644
--- a/wagtail/wagtailadmin/views/home.py
+++ b/wagtail/wagtailadmin/views/home.py
@@ -65,7 +65,7 @@ def home(request):
fn(request, panels)
return render(request, "wagtailadmin/home.html", {
- 'site_name': settings.VERDANT_SITE_NAME,
+ 'site_name': settings.WAGTAIL_SITE_NAME,
'panels': sorted(panels, key=lambda p: p.order),
'user':request.user
})
diff --git a/wagtail/wagtailadmin/views/pages.py b/wagtail/wagtailadmin/views/pages.py
index 10eafbe71..995a48207 100644
--- a/wagtail/wagtailadmin/views/pages.py
+++ b/wagtail/wagtailadmin/views/pages.py
@@ -334,7 +334,7 @@ def preview_on_edit(request, page_id):
request.META.pop('HTTP_X_REQUESTED_WITH', None) # Make this request appear to the page's serve method as a non-ajax one, as they will often implement custom behaviour for XHR
response = page.serve(request)
- response['X-Verdant-Preview'] = 'ok'
+ response['X-Wagtail-Preview'] = 'ok'
return response
else:
@@ -344,7 +344,7 @@ def preview_on_edit(request, page_id):
'page': page,
'edit_handler': edit_handler,
})
- response['X-Verdant-Preview'] = 'error'
+ response['X-Wagtail-Preview'] = 'error'
return response
@login_required
@@ -371,7 +371,7 @@ def preview_on_create(request, content_type_app_name, content_type_model_name, p
# as a front-end GET request
response = page.serve(request)
- response['X-Verdant-Preview'] = 'ok'
+ response['X-Wagtail-Preview'] = 'ok'
return response
else:
@@ -384,7 +384,7 @@ def preview_on_create(request, content_type_app_name, content_type_model_name, p
'parent_page': parent_page,
'edit_handler': edit_handler,
})
- response['X-Verdant-Preview'] = 'error'
+ response['X-Wagtail-Preview'] = 'error'
return response
def preview_placeholder(request):
diff --git a/wagtail/wagtailcore/migrations/0002_initial_data.py b/wagtail/wagtailcore/migrations/0002_initial_data.py
index 67cc896aa..f6c1d43c8 100644
--- a/wagtail/wagtailcore/migrations/0002_initial_data.py
+++ b/wagtail/wagtailcore/migrations/0002_initial_data.py
@@ -21,7 +21,7 @@ class Migration(DataMigration):
)
homepage = orm['wagtailcore.page'].objects.create(
- title="Welcome to your new Verdant site!",
+ title="Welcome to your new Wagtail site!",
slug='home',
content_type=page_content_type,
path='00010001',
diff --git a/wagtail/wagtaildocs/static/wagtaildocs/js/hallo-plugins/hallo-verdantdoclink.coffee b/wagtail/wagtaildocs/static/wagtaildocs/js/hallo-plugins/hallo-wagtaildoclink.coffee
similarity index 94%
rename from wagtail/wagtaildocs/static/wagtaildocs/js/hallo-plugins/hallo-verdantdoclink.coffee
rename to wagtail/wagtaildocs/static/wagtaildocs/js/hallo-plugins/hallo-wagtaildoclink.coffee
index fe1b505f2..180190cbd 100644
--- a/wagtail/wagtaildocs/static/wagtaildocs/js/hallo-plugins/hallo-verdantdoclink.coffee
+++ b/wagtail/wagtaildocs/static/wagtaildocs/js/hallo-plugins/hallo-wagtaildoclink.coffee
@@ -1,7 +1,7 @@
-# plugin for hallo.js to allow inserting links using Verdant's page chooser
+# plugin for hallo.js to allow inserting links using Wagtail's page chooser
(($) ->
- $.widget "IKS.halloverdantdoclink",
+ $.widget "IKS.hallowagtaildoclink",
options:
uuid: ''
editable: null
diff --git a/wagtail/wagtailembeds/static/wagtailembeds/js/hallo-plugins/hallo-verdantembeds.coffee b/wagtail/wagtailembeds/static/wagtailembeds/js/hallo-plugins/hallo-wagtailembeds.coffee
similarity index 97%
rename from wagtail/wagtailembeds/static/wagtailembeds/js/hallo-plugins/hallo-verdantembeds.coffee
rename to wagtail/wagtailembeds/static/wagtailembeds/js/hallo-plugins/hallo-wagtailembeds.coffee
index 841be3a74..9ce0cf58c 100644
--- a/wagtail/wagtailembeds/static/wagtailembeds/js/hallo-plugins/hallo-verdantembeds.coffee
+++ b/wagtail/wagtailembeds/static/wagtailembeds/js/hallo-plugins/hallo-wagtailembeds.coffee
@@ -1,7 +1,7 @@
# plugin for hallo.js to allow inserting embeds
(($) ->
- $.widget "IKS.halloverdantembeds",
+ $.widget "IKS.hallowagtailembeds",
options:
uuid: ''
editable: null
diff --git a/wagtail/wagtailimages/static/wagtailimages/js/hallo-plugins/hallo-verdantimage.coffee b/wagtail/wagtailimages/static/wagtailimages/js/hallo-plugins/hallo-wagtailimage.coffee
similarity index 92%
rename from wagtail/wagtailimages/static/wagtailimages/js/hallo-plugins/hallo-verdantimage.coffee
rename to wagtail/wagtailimages/static/wagtailimages/js/hallo-plugins/hallo-wagtailimage.coffee
index 57f097867..ab5e8a7ed 100644
--- a/wagtail/wagtailimages/static/wagtailimages/js/hallo-plugins/hallo-verdantimage.coffee
+++ b/wagtail/wagtailimages/static/wagtailimages/js/hallo-plugins/hallo-wagtailimage.coffee
@@ -1,7 +1,7 @@
-# plugin for hallo.js to allow inserting images from the Verdant image library
+# plugin for hallo.js to allow inserting images from the Wagtail image library
(($) ->
- $.widget "IKS.halloverdantimage",
+ $.widget "IKS.hallowagtailimage",
options:
uuid: ''
editable: null
diff --git a/wagtail/wagtailsearch/search.py b/wagtail/wagtailsearch/search.py
index 25d127967..86207ab81 100644
--- a/wagtail/wagtailsearch/search.py
+++ b/wagtail/wagtailsearch/search.py
@@ -54,7 +54,7 @@ class Search(object):
def __init__(self):
# Get settings
self.es_urls = getattr(settings, "WAGTAILSEARCH_ES_URLS", ["http://localhost:9200"])
- self.es_index = getattr(settings, "WAGTAILSEARCH_ES_INDEX", "verdant")
+ self.es_index = getattr(settings, "WAGTAILSEARCH_ES_INDEX", "wagtail")
# Get ElasticSearch interface
self.es = get_es(urls=self.es_urls)
diff --git a/wagtail/wagtailadmin/edit_handlers.py b/wagtail/wagtailadmin/edit_handlers.py
index cdcae4110..bc0dd3a2e 100644
--- a/wagtail/wagtailadmin/edit_handlers.py
+++ b/wagtail/wagtailadmin/edit_handlers.py
@@ -110,7 +110,7 @@ def formfield_for_dbfield(db_field, **kwargs):
return db_field.formfield(**kwargs)
-class VerdantAdminModelFormMetaclass(ClusterFormMetaclass):
+class WagtailAdminModelFormMetaclass(ClusterFormMetaclass):
# Override the behaviour of the regular ModelForm metaclass -
# which handles the translation of model fields to form fields -
# to use our own formfield_for_dbfield function to do that translation.
@@ -126,12 +126,12 @@ class VerdantAdminModelFormMetaclass(ClusterFormMetaclass):
if 'formfield_callback' not in attrs or attrs['formfield_callback'] is None:
attrs['formfield_callback'] = formfield_for_dbfield
- new_class = super(VerdantAdminModelFormMetaclass, cls).__new__(cls, name, bases, attrs)
+ new_class = super(WagtailAdminModelFormMetaclass, cls).__new__(cls, name, bases, attrs)
return new_class
-VerdantAdminModelForm = VerdantAdminModelFormMetaclass('VerdantAdminModelForm', (ClusterForm,), {})
+WagtailAdminModelForm = WagtailAdminModelFormMetaclass('WagtailAdminModelForm', (ClusterForm,), {})
-# Now, any model forms built off VerdantAdminModelForm instead of ModelForm should pick up
+# Now, any model forms built off WagtailAdminModelForm instead of ModelForm should pick up
# the nice form fields defined in FORM_FIELD_OVERRIDES.
@@ -166,7 +166,7 @@ def get_form_for_model(model, fields=None, exclude=None, formsets=None, exclude_
'Meta': type('Meta', (object,), attrs)
}
- return VerdantAdminModelFormMetaclass(class_name, (VerdantAdminModelForm,), form_class_attrs)
+ return WagtailAdminModelFormMetaclass(class_name, (WagtailAdminModelForm,), form_class_attrs)
def extract_panel_definitions_from_model_class(model, exclude=None):
diff --git a/wagtail/wagtailcore/models.py b/wagtail/wagtailcore/models.py
index 7c8c05750..3f44bfa67 100644
--- a/wagtail/wagtailcore/models.py
+++ b/wagtail/wagtailcore/models.py
@@ -50,10 +50,10 @@ class Site(models.Model):
else:
return 'http://%s:%d' % (self.hostname, self.port)
- # clear the verdant_site_root_paths cache whenever Site records are updated
+ # clear the wagtail_site_root_paths cache whenever Site records are updated
def save(self, *args, **kwargs):
result = super(Site, self).save(*args, **kwargs)
- cache.delete('verdant_site_root_paths')
+ cache.delete('wagtail_site_root_paths')
return result
@staticmethod
@@ -62,14 +62,14 @@ class Site(models.Model):
Return a list of (root_path, root_url) tuples, most specific path first -
used to translate url_paths into actual URLs with hostnames
"""
- result = cache.get('verdant_site_root_paths')
+ result = cache.get('wagtail_site_root_paths')
if result is None:
result = [
(site.id, site.root_page.url_path, site.root_url)
for site in Site.objects.select_related('root_page').order_by('-root_page__url_path')
]
- cache.set('verdant_site_root_paths', result, 3600)
+ cache.set('wagtail_site_root_paths', result, 3600)
return result
@@ -464,7 +464,7 @@ def get_navigation_menu_items():
# an exception here means that this node is one level deeper than any we've seen so far
depth_list.append(node)
# in Verdant, the convention is to have one root node in the db (depth=1); the menu proper
# begins with the children of that node (depth=2).
try:
root, root_children = depth_list[1]
@@ -464,7 +464,7 @@ def get_navigation_menu_items():
# an exception here means that this node is one level deeper than any we've seen so far
depth_list.append(node)
- # in Verdant, the convention is to have one root node in the db (depth=1); the menu proper
+ # in Wagtail, the convention is to have one root node in the db (depth=1); the menu proper
# begins with the children of that node (depth=2).
try: